@@ -1,12 +1,12 @@
-#' @title Generate a bi-criteria graph with uniformly randomly distribted edge weights.
+#' @title Generate a bi-criteria graph with two uniformly randomly distribted edge weights.
 #'
-#' @description No topology is defined. The instance is composed of two
+#' @description The instance is composed of two
 #' symmetric weight matrices. The first weight is drawn independently at
 #' random from a \eqn{\mathcal{R}[10, 100]} distribution, the second one
 #' from a \eqn{\mathcal{R}[10, 50]} distribution (see references).
 #'
 #' @note This is a simple wrapper around the much more flexible graph generation
-#' system (see, e.g., \code{\link{mcGP}}).
+#' system in package \pkg{grapherator}.
 #'
 #' @references
 #' Zhou, G. and Gen, M. Genetic Algorithm Approach on Multi-Criteria
@@ -20,17 +20,18 @@
 #'
 #' @param n [\code{integer(1)}]\cr
 #'   Instance size, i.e., number of nodes.
-#' @return [\code{mcGP}]
+#' @template ret_grapherator
 #' @examples
 #' g = genRandomMCGP(10L)
 #' \dontrun{
-#' pl = plot(g)
+#' pl = grapherator::plot(g)
 #' }
 #' @export
 genRandomMCGP = function(n) {
   n = asInt(n, lower = 2L)
-  g = mcGP(lower = 10, upper = 100)
-  g = addWeights(g, n = n, method = "random", weight.fun = runif, symmetric = TRUE, min = 10, max = 100)
-  g = addWeights(g, method = "random", weight.fun = runif, symmetric = TRUE, min = 10, max = 50)
+  g = grapherator::graph(lower = 0, upper = 100)
+  g = grapherator::addNodes(g, n = n, generator = grapherator::addNodesUniform)
+  g = grapherator::addWeights(g, generator = grapherator::addWeightsRandom, method = runif, symmetric = TRUE, min = 10, max = 100, to.int = TRUE)
+  g = grapherator::addWeights(g, generator = grapherator::addWeightsRandom, method = runif, symmetric = TRUE, min = 10, max = 50, to.int = TRUE)
   return(g)
 }
