@@ -6,10 +6,12 @@
 #   Problem instance
 # @return [\code{numeric(2)}]
 getReferencePoint = function(instance) {
-  assertClass(instance, "mcGP")
-  n = instance$n.nodes
+  assertClass(instance, "grapherator")
+  n = grapherator::getNumberOfNodes(instance)
 
   sapply(instance$weights, function(wmat) {
-    sum(sort(as.numeric(wmat), decreasing = TRUE)[1:n])
+    wmat = as.numeric(wmat)
+    wmat = wmat[!is.infinite(wmat)]
+    sum(sort(wmat, decreasing = TRUE)[1:n])
   })
 }
