@@ -36,6 +36,8 @@
 #' @param max.iter [\code{integer(1)}]\cr
 #'   Maximal number of iterations.
 #'   Default is \code{100}.
+#' @param ... [\code{any}]\cr
+#'   Further parameters passed to mutator.
 #' @template ret_ecrresult
 #' @examples
 #' inst = genRandomMCGP(10)
@@ -51,17 +53,18 @@ mcMSTEmoaBG = function(instance,
   mut = NULL,
   selMating = NULL, selSurvival = ecr::selNondom,
   ref.point = NULL,
-  max.iter = 100L) {
+  max.iter = 100L,
+  ...) {
 
   # get number of nodes
-  n = instance$n.nodes
-  n.objectives = instance$n.weights
+  n = grapherator::getNumberOfNodes(instance)
+  n.objectives = grapherator::getNumberOfWeights(instance)
 
   force(instance)
 
   # default is our subgraph mutator
   if (is.null(mut))
-    mut = setup(mutSubgraphMST, instance = instance)
+    mut = setup(mutSubgraphMST, instance = instance, ...)
 
   if (is.null(ref.point))
     ref.point = getReferencePoint(instance)
@@ -73,8 +76,9 @@ mcMSTEmoaBG = function(instance,
   # now generate an initial population, i.e.,
   # a list of edge lists
   population = lapply(1:mu, function(i) {
-    pcode = sample(1:n, n - 2L, replace = TRUE)
-    prueferToEdgeList(pcode)
+    #pcode = sample(1:n, n - 2L, replace = TRUE)
+    #prueferToEdgeList(pcode)
+    getRandomSpanningTree(instance)
   })
 
   res = ecr(fitness.fun = fitness.fun, n.objectives = n.objectives,
