@@ -4,8 +4,7 @@
 #' graph problem by iteratively applying Prim's algorithm for the single-objective
 #' MST problem to a scalarized version of the problem. I.e., the weight vector
 #' \eqn{(w_1, w_2)} of an edge \eqn{(i, j)} is substituted with a weighted
-#' sum \eqn{\lambda_i w_1 + (1 - \lambda_i) w_2} with weight \eqn{\lambda_i \in [0, 1]}
-#' for different weights.
+#' sum \eqn{\lambda_i w_1 + (1 - \lambda_i) w_2} for different weights \eqn{\lambda_i \in [0, 1]}.
 #'
 #' @note Note that this procedure can only find socalled supported efficient
 #' solutions, i.e., solutions on the convex hull of the Pareto-optimal front.
@@ -15,8 +14,8 @@
 #' of the 2001 Congress on Evolutionary Computation (IEEE Cat. No.01TH8546),
 #' vol. 1, 2001, pp. 544–551 vol. 1.
 #'
-#' @param instance [\code{mcGP}]\cr
-#'   Multi-objective graph problem.
+#' @param instance [\code{\link[grapherator]{grapherator}}]\cr
+#'   Graph.
 #' @param n.lambdas [\code{integer(1) | NULL}]\cr
 #'   Number of weights to generate. The weights are generated equdistantly
 #'   in the interval \eqn{[0, 1]}.
@@ -31,8 +30,9 @@
 #' @export
 #FIXME: generalize to > 2 objectives
 mcMSTPrim = function(instance, n.lambdas = NULL, lambdas = NULL) {
-  assertClass(instance, "mcGP")
-  if (instance$n.weights != 2L)
+  assertClass(instance, "grapherator")
+  n.weights = grapherator::getNumberOfWeights(instance)
+  if (n.weights != 2L)
     stopf("mcMSTPrim: At the moment only bi-objective problems supported.")
   if (is.null(n.lambdas) & is.null(lambdas))
     stopf("mcMSTPrim: At least n.lambdas or lambdas must be set.")
@@ -42,10 +42,8 @@ mcMSTPrim = function(instance, n.lambdas = NULL, lambdas = NULL) {
   }
   assertNumeric(lambdas, any.missing = FALSE, all.missing = FALSE)
 
-  #FIXME: also return pareto.set as Pruefer number (needs
-  # transformation edgelistToPrueferCode)
-  #pareto.set = matrix(0, nrow = )
-  pareto.front = matrix(0, ncol = length(lambdas), nrow = instance$n.weights)
+  pareto.set = vector(mode = "list", length = length(lambdas))
+  pareto.front = matrix(0, ncol = length(lambdas), nrow = n.weights)
 
   # Helper function to build the weighted sum
   # of edge weights
@@ -54,7 +52,11 @@ mcMSTPrim = function(instance, n.lambdas = NULL, lambdas = NULL) {
     assertList(weights, types = "matrix")
     assertNumber(lambda, lower = 0, upper = 1)
 
-    lambda * weights[[1L]] + (1 - lambda) * weights[[2L]]
+    dmat = lambda * weights[[1L]] + (1 - lambda) * weights[[2L]]
+
+    if (!is.null(instance$adj.mat))
+      dmat[!instance$adj.mat] = 1e7 # FIXME: magic number
+    return(dmat)
   }
 
   n = instance$n.nodes
@@ -65,13 +67,15 @@ mcMSTPrim = function(instance, n.lambdas = NULL, lambdas = NULL) {
     mst.res = vegan::spantree(d = weight.mat)
     nodes1 = 2:n
     nodes2 = mst.res$kid
+    edgelist = matrix(c(nodes1, nodes2), byrow = TRUE, nrow = 2L)
 
-    mst.costs = c(0, 0)
-    for (i in 1:(n - 1)) {
-      mst.costs = mst.costs + c(instance$weights[[1L]][nodes1[i], nodes2[i]],
-        instance$weights[[2L]][nodes1[i], nodes2[i]])
-    }
-    pareto.front[, k] = mst.costs
+    pareto.front[, k] = getWeight(instance, edgelist = edgelist)
+    pareto.set[[k]] = edgelist
   }
-  return(list(pareto.front = pareto.front))
+
+  return(list(
+    pareto.set = pareto.set,
+    pareto.front = pareto.front)
+  )
 }
+
